.. Flask-Dance documentation master file, created by
   sphinx-quickstart on Sat Sep 27 09:47:52 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Flask-Dance
===========

Doing the OAuth dance with style using `Flask`_, `requests`_, and `oauthlib`_.
Currently, only OAuth consumers are supported, but this project could
easily support OAuth providers in the future, as well.

.. _Flask: http://flask.pocoo.org/
.. _requests: http://python-requests.org/
.. _oauthlib: https://oauthlib.readthedocs.org/

Contents:

.. toctree::
   :maxdepth: 2

   quickstart
   contrib
   consumers
   token-storage
   signals
   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

